@@ -27,7 +27,7 @@ header.textile <- function(caption = NULL, caption.level = NULL, frame = NULL, w
 
   if (!is.null(caption)) {
     if (!is.null(caption.level)) {
-      if (is.numeric(caption.level) & caption.level > 0) { lev <- paste("h", caption.level, ".", sep = "") ; res <- paste(lev, " ", caption, " ", lev, "\n\n", sep = "") }
+      if (is.numeric(caption.level) & caption.level > 0) { lev <- paste("h", caption.level, ".", sep = "") ; res <- paste(lev, " ", caption, "\n\n", sep = "") }
       else if (caption.level == "s") res <- paste(beauty.textile(caption, "s"), "\n\n", sep = "")
       else if (caption.level == "e") res <- paste(beauty.textile(caption, "e"), "\n\n", sep = "")
       else if (caption.level == "m") res <- paste(beauty.textile(caption, "m"), "\n\n", sep = "")
